diff --git a/commands.go b/commands.go
index c2d832d..8ff8846 100644
--- a/commands.go
+++ b/commands.go
@@ -162,14 +162,14 @@ func parseCommand(user *gumble.User, username, command string) {
}
// Shuffleon command
- case dj.conf.Aliases.ShuffleOnAlias:
+ case dj.conf.Aliases.ShuffleOnAlias:
if dj.HasPermission(username, dj.conf.Permissions.AdminShuffleToggle) {
toggleAutomaticShuffle(true, user, username)
} else {
dj.SendPrivateMessage(user, NO_PERMISSION_MSG)
}
- // Shuffleoff command
+ // Shuffleoff command
case dj.conf.Aliases.ShuffleOffAlias:
if dj.HasPermission(username, dj.conf.Permissions.AdminShuffleToggle) {
toggleAutomaticShuffle(false, user, username)
diff --git a/parseconfig.go b/parseconfig.go
index e3dc403..c69e8b3 100644
--- a/parseconfig.go
+++ b/parseconfig.go
@@ -52,7 +52,7 @@ type DjConfig struct {
NumCachedAlias string
CacheSizeAlias string
KillAlias string
- ShuffleAlias string
+ ShuffleAlias string
ShuffleOnAlias string
ShuffleOffAlias string
}
@@ -74,8 +74,8 @@ type DjConfig struct {
AdminNumCached bool
AdminCacheSize bool
AdminKill bool
- AdminShuffle bool
- AdminShuffleToggle bool
+ AdminShuffle bool
+ AdminShuffleToggle bool
}
}
diff --git a/songqueue.go b/songqueue.go
index 182455d..f36e973 100644
--- a/songqueue.go
+++ b/songqueue.go
@@ -65,7 +65,7 @@ func (q *SongQueue) NextSong() {
func (q *SongQueue) PeekNext() (Song, error) {
if q.Len() > 1 {
if dj.conf.General.AutomaticShuffleOn{ //Shuffle mode is active
- q.RandomNextSong(false)
+ q.RandomNextSong(false)
}
return q.queue[1], nil
}
@@ -122,7 +122,7 @@ func (q *SongQueue) ShuffleSongs() {
}
// Sets a random song as next song to be played
-// queueWasEmpty wether the queue was empty before adding the last Song
+// queueWasEmpty wether the queue was empty before adding the last song
func (q *SongQueue) RandomNextSong(queueWasEmpty bool){
nextSongIndex := 1
if queueWasEmpty{
diff --git a/strings.go b/strings.go
index 5d17e25..8e19199 100644
--- a/strings.go
+++ b/strings.go
@@ -71,11 +71,11 @@ const CACHE_SIZE_MSG = "The cache is currently %g MB in size."
// Message shown to user when they attempt to issue a cache-related command when caching is not enabled.
const CACHE_NOT_ENABLED_MSG = "The cache is not currently enabled."
-// Message shown to user when they attempt to shuffle the a playlist with less than 2 elements.
-const CANT_SHUFFLE_MSG = "Can't shuffle the playlist if there is less than 2 songs."
+// Message shown to user when they attempt to shuffle the queue and it has less than 2 elements.
+const CANT_SHUFFLE_MSG = "Can't shuffle the queue if there is less than 2 songs."
-// Message shown to users when the playlist has been successfully shuffled.
-const SHUFFLE_SUCCESS_MSG = "The current playlist has been successfully shuffled by %s (starting from next song)."
+// Message shown to users when the songqueue has been successfully shuffled.
+const SHUFFLE_SUCCESS_MSG = "The current songqueue has been successfully shuffled by %s (starting from next song)."
// Message shown to users when automatic shuffle is activated
const SHUFFLE_ON_MESSAGE = "%s has turned automatic shuffle on."
@@ -125,9 +125,9 @@ const HELP_HTML = `
!reset - An admin command that resets the song queue.
!forceskip - An admin command that forces a song skip.
!forceskipplaylist - An admin command that forces a playlist skip.
-!shuffle - An admin command that shuffles the current playlist.
+!shuffle - An admin command that shuffles the current queue.
!shuffleon - An admin command that enables auto shuffling.
-!shuffleoff - An admin command that disables auto shuffling.
+!shuffleoff - An admin command that disables auto shuffling.
!move - Moves MumbleDJ into channel if it exists.
!reload - Reloads mumbledj.gcfg configuration settings.
!setcomment - Sets the comment for the bot.